package tk.antoine.roux.domain.model;

public final class Either<T> {
    private final Exception error;
    private final T success;

    private Either(Exception error, T success) {
        this.error = error;
        this.success = success;
    }

    public Exception left() {
        return error;
    }

    public T right() {
        return success;
    }

    public static <T> Either<T> right(T success) {
        return new Either<>(null, success);
    }

    public static <T> Either<T> left(Exception error) {
        return new Either<>(error, null);
    }

    public boolean isLeft() {
        return success == null;
    }

    public boolean isRight() {
        return error == null;
    }

}
