package tk.antoine.roux.infrastructure;

import org.springframework.http.HttpStatus;
import org.springframework.http.ProblemDetail;
import org.springframework.http.ResponseEntity;
import tk.antoine.roux.domain.model.Either;

public interface Manager {

    static <T> ResponseEntity<T> eitherToResponseEntity(Either<T> either, String errorMessage) {
        ResponseEntity<T> response;
        if (either.isLeft()) {
            ProblemDetail problemDetail = exceptionToProblemDetail(either, errorMessage);
            response = ResponseEntity.of(problemDetail).build();
        } else {
            response = ResponseEntity.ok(either.right());
        }
        return response;
    }

    private static ProblemDetail exceptionToProblemDetail(Either<?> either, String errorMessage) {
        ProblemDetail problemDetail = ProblemDetail
            .forStatusAndDetail(HttpStatus.BAD_REQUEST, either.left().getMessage());
        problemDetail.setTitle(errorMessage);
        return problemDetail;
    }
}
